@@ -43,6 +43,18 @@ if FOAM_REF_VERSION( ">=", "010700" ):
     pass
 
 
+#--------------------------------------------------------------------------------------
+if FOAM_REF_VERSION( ">=", "020000" ):
+    from scalarTransportFlux.r2_0_0 import *
+    pass
+
+
+#--------------------------------------------------------------------------------------
+if FOAM_REF_VERSION( ">=", "020100" ):
+    from scalarTransportFlux.r2_1_0 import *
+    pass
+
+
 #--------------------------------------------------------------------------------------
 def entry_point():
     try:
