@@ -89,7 +89,7 @@ def main_standalone( argc, argv ):
         ext_Info() << "Time = " << runTime.timeName() << nl << nl
         
         from Foam.finiteVolume.cfdTools.general.include import readSIMPLEControls
-        simple, nNonOrthCorr, momentumPredictor, fluxGradp, transonic = readSIMPLEControls( mesh )
+        simple, nNonOrthCorr, momentumPredictor, transonic = readSIMPLEControls( mesh )
         
         from Foam.finiteVolume import solve
         from Foam import fvm
@@ -108,8 +108,8 @@ def main_standalone( argc, argv ):
 
 #--------------------------------------------------------------------------------------
 import sys, os
-from Foam import FOAM_REF_VERSION
-if FOAM_REF_VERSION( "==", "010600" ):
+from Foam import FOAM_VERSION
+if FOAM_VERSION( ">=", "010700" ):
    if __name__ == "__main__" :
       argv = sys.argv
       os._exit( main_standalone( len( argv ), argv ) )
@@ -117,9 +117,9 @@ if FOAM_REF_VERSION( "==", "010600" ):
    pass
 else:
    from Foam.OpenFOAM import ext_Info
-   ext_Info()<< "\nTo use this solver, It is necessary to SWIG OpenFoam1.6 \n "
+   ext_Info()<< "\nTo use this solver, It is necessary to SWIG OpenFoam1.7.0 or higher \n "
    pass
-	
+
 	
 #--------------------------------------------------------------------------------------
 
